@@ -26,16 +26,17 @@
 import sys
 
 from fs import open_fs, path
-from PyQt5 import QtWidgets
+from PyQt5 import QtWidgets, QtGui
 from fslib import ui_filepicker
+from fslib.utils import match_extension
 
 class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
-    def __init__(self, parent=None, fs_name=u"~/", file_pattern=u'*.*', title=u'FS File Picker'):
+    def __init__(self, parent=None, fs_url=u"~/", file_pattern=u'*.*', title=u'FS File Picker'):
         super(FilePicker, self).__init__(parent)
         self.setupUi(self)
         self.filename = None
         self.setWindowTitle(title)
-        self.fs_name = fs_name
+        self.fs_url = fs_url
         self.home_fs = None
         self.last_index = 0
         self.file_pattern = file_pattern
@@ -47,8 +48,9 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
 
     def browse_folder(self):
         self.DirList.clear()
-        self.home_fs = open_fs(self.fs_name)
-        for dir_path in self.home_fs.walk.dirs():
+        self.home_fs = open_fs(self.fs_url)
+        self.DirList.addItem(u'.')
+        for dir_path in self.home_fs.walk.dirs(ignore_errors=True):
             self.DirList.addItem(dir_path)
         self.selection_directory(0)
         self.DirList.currentIndexChanged.connect(self.selection_directory)
@@ -58,29 +60,37 @@ class FilePicker(QtWidgets.QDialog, ui_filepicker.Ui_Dialog):
         selected_dir = self.DirList.currentText()
         self.FileList.clear()
         file_type = self.file_type.text()
-        for files in self.home_fs.walk.files(selected_dir, filter=[unicode(file_type)]):
-            self.FileList.addItem(files)
+        for item in self.home_fs.listdir(selected_dir):
+            if not self.home_fs.isdir(item) and match_extension(item, [file_type]):
+                    self.FileList.addItem(item)
+        if self.last_index == 0:
+            self.FileList.setCurrentRow(0)
 
     def selection_file_type(self):
         self.selection_directory(self.last_index)
+        self.FileList.setCurrentRow(-1)
 
     def cancel(self):
         self.close()
 
     def open(self):
-        self.filename = self.FileList.item(self.FileList.currentRow()).text()
-        self.close()
+        try:
+            self.filename = self.FileList.item(self.FileList.currentRow()).text()
+        except AttributeError:
+            pass
+        else:
+            self.close()
 
 
-def fs_filepicker(parent=None, fs_name=u'~/', file_pattern=u'*.*', title=u'FS File Picker'):
+def fs_filepicker(parent=None, fs_url=u'~/', file_pattern=u'*.*', title=u'FS File Picker'):
     if parent is None:
         app = QtWidgets.QApplication(sys.argv)
-    form = FilePicker(parent, fs_name, file_pattern, title=title)
+    form = FilePicker(parent, fs_url, file_pattern, title=title)
     form.show()
     if parent is None:
         app.exec_()
 
-    fs_path = path.combine(form.fs_name, form.filename)
+    fs_path = path.combine(form.fs_url, form.filename)
     return fs_path
 
 if __name__ == '__main__':
